@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.112';
+our $VERSION = '0.113';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Thu Nov  8 14:20:42 2018 GMT
+# on Thu Dec 13 16:32:20 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1714,9 +1714,9 @@ __PACKAGE__->status( add => 24946, iridium => '-', 'Iridium 33', 'Tumbling' );
 __PACKAGE__->status( add => 24947, iridium => 'D', 'Iridium 27', 'Decayed 2002-02-01' );
 __PACKAGE__->status( add => 24948, iridium => '-', 'Iridium 28', 'Tumbling' );
 __PACKAGE__->status( add => 24949, iridium => 'D', 'Iridium 30', 'Decayed 2017-09-28' );
-__PACKAGE__->status( add => 24950, iridium => 'S', 'Iridium 31', '' );
+__PACKAGE__->status( add => 24950, iridium => '-', 'Iridium 31', 'Tumbling' );
 __PACKAGE__->status( add => 24965, iridium => 'D', 'Iridium 19', 'Decayed 2018-04-07' );
-__PACKAGE__->status( add => 24966, iridium => 'S', 'Iridium 35', '' );
+__PACKAGE__->status( add => 24966, iridium => '-', 'Iridium 35', 'Tumbling' );
 __PACKAGE__->status( add => 24967, iridium => '-', 'Iridium 36', 'Tumbling' );
 __PACKAGE__->status( add => 24968, iridium => 'D', 'Iridium 37', 'Decayed 2018-05-26' );
 __PACKAGE__->status( add => 24969, iridium => 'D', 'Iridium 34', 'Decayed 2018-01-08' );
@@ -1784,8 +1784,8 @@ __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-0
 
 # Summary:
 # Operational [+]: 8
-#       Spare [S]: 7
-#    Tumbling [-]: 33
+#       Spare [S]: 5
+#    Tumbling [-]: 35
 #     Decayed [D]: 49
 
 1;
